/// <reference types="node" />
import type { ChildProcess, SpawnOptions } from 'child_process';
import type { Server, Socket } from 'net';
import type { Plugin } from 'rollup';
interface SerializeCapableObject {
    [K: string]: SerializeCapable;
}
declare type SerializeCapable = string | SerializeCapableObject | number | boolean;
export interface EventMap {
    close: (code: number, signal: NodeJS.Signals) => void;
    disconnect: () => void;
    error: (err: Error) => void;
    exit: (code: number | null, signal: NodeJS.Signals | null) => void;
    message: (message: SerializeCapable, sendHandle: Socket | Server) => void;
}
export declare type EventType = keyof EventMap;
export interface EventItemFromMap<K extends EventType> {
    event: K;
    listener: EventMap[K];
}
export declare type EventItem = EventItemFromMap<'close'> | EventItemFromMap<'disconnect'> | EventItemFromMap<'error'> | EventItemFromMap<'exit'> | EventItemFromMap<'message'>;
export declare type EventList = Array<EventItem>;
export interface SpawnProcessOptions extends SpawnOptions {
    command?: string;
    file?: string | null;
    args?: readonly string[];
    key?: string;
    global?: boolean | string;
    events?: Partial<EventMap> | EventList;
    setup?: (proc: ChildProcess) => void;
    cleanup?: (proc: ChildProcess) => void;
}
export declare function spawnProcess(options?: SpawnProcessOptions): Plugin;
export {};
//# sourceMappingURL=index.d.ts.map