'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var spawn = require('cross-spawn');
var path = require('path');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var spawn__default = /*#__PURE__*/_interopDefaultLegacy(spawn);

function resolveFileFromBuild(options, bundle) {
    var file = options.file;
    if (file) {
        return file;
    }
    var filename = Object.values(bundle)
        .map(function (output) { return (output.type === 'chunk' ? output.fileName : null); })
        .filter(function (filename) { return !!filename; })
        .find(function (filename) { return path.extname(filename) === '.js'; });
    return path.join(options.dir, filename);
}
function spawnProcess(options) {
    options = options || {};
    var command = options.command;
    var file = options.file;
    var args = options.args;
    var key = options.key;
    var storeGlobal = options.global;
    var eventsOption = options.events;
    var setup = options.setup;
    var cleanup = options.cleanup;
    var procKey = key || 'spawn-process';
    delete options.command;
    delete options.file;
    delete options.args;
    delete options.key;
    delete options.global;
    delete options.events;
    delete options.setup;
    delete options.cleanup;
    var resolveFilename = ((file || file === null)
        ? function () { return file; }
        : resolveFileFromBuild);
    var globalKey = storeGlobal;
    if (globalKey == null) {
        globalKey = !!process.env.ROLLUP_WATCH;
    }
    globalKey = !globalKey ? null : globalKey === true ? 'ROLLUP_PLUGIN_SPAWN_PROCESS_CONTEXT' : globalKey;
    var context = !globalKey ? {} : global[globalKey] || (global[globalKey] = {});
    var events = !eventsOption ? [] : Array.isArray(eventsOption) ? eventsOption : Object.keys(eventsOption).map(function (event) { return ({
        event: event,
        listener: eventsOption[event],
    }); });
    var eventsLength = events.length;
    return {
        name: 'spawn-process',
        writeBundle: function writeBundle(outputOptions, bundle) {
            var stored = context[procKey];
            if (stored) {
                var prevProc = stored.proc;
                var prevEvents = stored.events;
                if (cleanup) {
                    cleanup(prevProc);
                }
                for (var p = prevEvents.length - 1; p >= 0; p--) {
                    var prevItem = prevEvents[p];
                    prevProc.off(prevItem.event, prevItem.listener);
                }
                prevProc.kill();
            }
            var filename = resolveFilename(outputOptions, bundle);
            var spawnArgs = filename ? [filename] : [];
            if (args) {
                spawnArgs.push.apply(spawnArgs, args);
            }
            var proc = spawn__default['default'](command || 'node', spawnArgs, options);
            for (var i = 0; i < eventsLength; i++) {
                var eventItem = events[i];
                proc.on(eventItem.event, eventItem.listener);
            }
            context[procKey] = { proc: proc, events: events };
            if (setup) {
                setup(proc);
            }
        },
    };
}

exports.spawnProcess = spawnProcess;
//# sourceMappingURL=spawn-process.cjs.map
